@@ -1,16 +1,14 @@
-# -*- coding: utf-8 -*-
 
 import os
-import six
-import sys
 
 import pytest
 
 from translate.convert import convert
 
 
-class TestConvertCommand(object):
+class TestConvertCommand:
     """Tests running actual commands on files"""
+
     convertmodule = convert
     defaultoptions = {"progress": "none"}
 
@@ -44,7 +42,7 @@ class TestConvertCommand(object):
         argv = list(argv)
         kwoptions = getattr(self, "defaultoptions", {}).copy()
         kwoptions.update(kwargs)
-        for key, value in six.iteritems(kwoptions):
+        for key, value in kwoptions.items():
             if value is True:
                 argv.append("--%s" % key)
             else:
@@ -73,7 +71,7 @@ class TestConvertCommand(object):
 
     def create_testfile(self, filename, contents):
         """creates the given file in the testdirectory with the given contents"""
-        if isinstance(contents, six.text_type):
+        if isinstance(contents, str):
             contents = contents.encode('utf-8')
         testfile = self.open_testfile(filename, "wb")
         testfile.write(contents)
@@ -97,18 +95,13 @@ class TestConvertCommand(object):
             assert newoptions == []
         return "\n".join(newoptions)
 
-    def test_help(self):
+    def test_help(self, capsys):
         """tests getting help (returning the help_string so further tests can be done)"""
-        stdout = sys.stdout
-        helpfile = self.open_testfile("help.txt", "w")
-        sys.stdout = helpfile
-        try:
-            pytest.raises(SystemExit, self.run_command, help=True)
-        finally:
-            sys.stdout = stdout
-        helpfile.close()
-        help_string = self.read_testfile("help.txt").decode('utf-8')
-        print(help_string)
+        with pytest.raises(SystemExit):
+            self.run_command(help=True)
+        help_string, err = capsys.readouterr()
+        # normalize newlines
+        help_string = help_string.replace('\r\n', '\n').replace('\r', '\n')
         convertsummary = self.convertmodule.__doc__.split("\n")[0]
         # the convertsummary might be wrapped. this will probably unwrap it
         assert convertsummary in help_string.replace("\n", " ")
