@@ -1,31 +1,31 @@
-# -*- coding: utf-8 -*-
+
+from io import BytesIO
 
 from pytest import mark
 
 from translate.convert import dtd2po, test_convert
-from translate.misc import wStringIO
 from translate.storage import dtd, po
 
 
-class TestDTD2PO(object):
+class TestDTD2PO:
 
     def dtd2po(self, dtdsource, dtdtemplate=None):
         """helper that converts dtd source to po source without requiring files"""
-        inputfile = wStringIO.StringIO(dtdsource)
+        inputfile = BytesIO(dtdsource.encode())
         inputdtd = dtd.dtdfile(inputfile)
         convertor = dtd2po.dtd2po()
         if dtdtemplate is None:
             outputpo = convertor.convertstore(inputdtd)
         else:
-            templatefile = wStringIO.StringIO(dtdtemplate)
+            templatefile = BytesIO(dtdtemplate.encode())
             templatedtd = dtd.dtdfile(templatefile)
             outputpo = convertor.mergestore(templatedtd, inputdtd)
         return outputpo
 
     def convertdtd(self, dtdsource):
         """call the convertdtd, return the outputfile"""
-        inputfile = wStringIO.StringIO(dtdsource)
-        outputfile = wStringIO.StringIO()
+        inputfile = BytesIO(dtdsource.encode())
+        outputfile = BytesIO()
         templatefile = None
         assert dtd2po.convertdtd(inputfile, outputfile, templatefile)
         return outputfile.getvalue()
@@ -63,7 +63,7 @@ class TestDTD2PO(object):
         """checks that the convertdtd function is working"""
         dtdsource = '<!ENTITY saveas.label "Save As...">\n'
         posource = self.convertdtd(dtdsource)
-        pofile = po.pofile(wStringIO.StringIO(posource))
+        pofile = po.pofile(BytesIO(posource))
         unit = self.singleelement(pofile)
         assert unit.source == "Save As..."
         assert unit.target == ""
@@ -95,8 +95,8 @@ class TestDTD2PO(object):
         """checks that two empty entitu definitions have correct context (bug 2190)."""
         dtdsource = '<!ENTITY community.exp.start "">\n<!ENTITY contribute.end "">\n'
         pofile = self.dtd2po(dtdsource)
-        assert pofile.units[-2].getcontext() == u"community.exp.start"
-        assert pofile.units[-1].getcontext() == u"contribute.end"
+        assert pofile.units[-2].getcontext() == "community.exp.start"
+        assert pofile.units[-1].getcontext() == "contribute.end"
 
     def test_emptyentity_translated(self):
         """checks that if we translate an empty entity it makes it into the PO, bug 101"""
@@ -215,7 +215,7 @@ class TestDTD2PO(object):
         assert self.countelements(pofile) == 2
 
     def test_carriage_return_in_multiline_dtd(self):
-        """test that we create nice PO files when we find a \r\n in a multiline DTD element"""
+        r"""test that we create nice PO files when we find a \r\n in a multiline DTD element"""
         dtdsource = ('<!ENTITY  noupdatesfound.intro "First line then \r\n'
                      '                                next lines.">\n')
         pofile = self.dtd2po(dtdsource)
@@ -303,9 +303,9 @@ Some other text
         pofile = self.dtd2po(dtdlanguage, dtdtemplate)
         print(pofile)
         assert pofile.units[3].source == "Manage Certificates..."
-        assert pofile.units[3].target == u"ﺇﺩﺍﺭﺓ ﺎﻠﺸﻫﺍﺩﺎﺗ..."
+        assert pofile.units[3].target == "ﺇﺩﺍﺭﺓ ﺎﻠﺸﻫﺍﺩﺎﺗ..."
         assert pofile.units[4].source == "M"
-        assert pofile.units[4].target == u"ﺩ"
+        assert pofile.units[4].target == "ﺩ"
 
     @mark.xfail(reason="Not Implemented")
     def test_accelerator_keys_not_in_sentence(self):
@@ -316,14 +316,15 @@ Some other text
 <!ENTITY useAutoScroll.accesskey         "a">'''
         pofile = self.dtd2po(dtdlanguage, dtdtemplate)
         print(pofile)
-        assert pofile.units[1].target == "使用自動捲動(&Autoscrolling)"
+        expected_target = "使用自動捲動(&Autoscrolling)".decode('utf-8')
+        assert pofile.units[1].target == expected_target
         # We assume that accesskeys with no associated key should be done as follows "XXXX (&A)"
         # TODO - check that we can unfold this from PO -> DTD
         dtdlanguage = '''<!ENTITY useAutoScroll.label             "使用自動捲動">
 <!ENTITY useAutoScroll.accesskey         "a">'''
         pofile = self.dtd2po(dtdlanguage, dtdtemplate)
         print(pofile)
-        assert pofile.units[1].target == "使用自動捲動 (&A)"
+        assert pofile.units[1].target == "使用自動捲動 (&A)".decode('utf-8')
 
     def test_exclude_entity_includes(self):
         """test that we don't turn an include into a translatable string"""
@@ -364,12 +365,13 @@ Some other text
 
 class TestDTD2POCommand(test_convert.TestConvertCommand, TestDTD2PO):
     """Tests running actual dtd2po commands on files"""
+
     convertmodule = dtd2po
     defaultoptions = {"progress": "none"}
 
-    def test_help(self):
+    def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self)
+        options = test_convert.TestConvertCommand.test_help(self, capsys)
         options = self.help_check(options, "-P, --pot")
         options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "--duplicates=DUPLICATESTYLE", last=True)
