@@ -1,14 +1,12 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
-from translate.convert import oo2po
-from translate.convert import po2oo
-from translate.convert import test_convert
-from translate.misc import wStringIO
-from translate.storage import po
-from translate.storage.poheader import poheader
-from translate.storage import oo
 import os
+from io import BytesIO
+from urllib import parse
+
+from translate.convert import oo2po, po2oo, test_convert
+from translate.storage import oo, po
+from translate.storage.poheader import poheader
+
 
 class TestOO2PO:
     target_filetype = po.pofile
@@ -17,6 +15,8 @@ class TestOO2PO:
 
     def convert(self, oosource, sourcelanguage='en-US', targetlanguage='af-ZA'):
         """helper that converts oo source to po source without requiring files"""
+        if isinstance(oosource, str):
+            oosource = oosource.encode('utf-8')
         inputoo = oo.oofile(oosource)
         convertor = self.conversion_class(sourcelanguage, targetlanguage)
         outputpo = convertor.convertstore(inputoo)
@@ -33,26 +33,28 @@ class TestOO2PO:
             return pofile.units[0]
 
     def roundtripstring(self, filename, entitystring):
-        """Convert the supplied string as part of an OpenOffice.org GSI file to po and back.
-        
-        Return the string once it has been through all the conversions."""
+        """
+        Convert the supplied string as part of an OpenOffice.org GSI file to po and back.
+
+        Return the string once it has been through all the conversions.
+        """
 
         ootemplate = r'helpcontent2	%s	0	help	par_id3150670 35				0	en-US	%s				2002-02-02 02:02:02'
 
-        oosource = ootemplate % (filename, entitystring)
-        ooinputfile = wStringIO.StringIO(oosource)
-        ootemplatefile = wStringIO.StringIO(oosource)
-        pooutputfile = wStringIO.StringIO()
+        oosource = (ootemplate % (filename, entitystring)).encode('utf-8')
+        ooinputfile = BytesIO(oosource)
+        ootemplatefile = BytesIO(oosource)
+        pooutputfile = BytesIO()
 
         self.conversion_module.convertoo(ooinputfile, pooutputfile, ootemplatefile, targetlanguage='en-US')
         posource = pooutputfile.getvalue()
 
-        poinputfile = wStringIO.StringIO(posource)
-        ootemplatefile = wStringIO.StringIO(oosource)
-        oooutputfile = wStringIO.StringIO()
+        poinputfile = BytesIO(posource)
+        ootemplatefile = BytesIO(oosource)
+        oooutputfile = BytesIO()
         po2oo.convertoo(poinputfile, oooutputfile, ootemplatefile, targetlanguage="en-US")
-        ooresult = oooutputfile.getvalue()
-        print "original oo:\n", oosource, "po version:\n", posource, "output oo:\n", ooresult
+        ooresult = oooutputfile.getvalue().decode('utf-8')
+        print("original oo:\n", oosource, "po version:\n", posource, "output oo:\n", ooresult)
         return ooresult.split('\t')[10]
 
     def check_roundtrip(self, filename, text):
@@ -73,15 +75,15 @@ class TestOO2PO:
         pofile = self.convert(oosource)
         pounit = self.singleelement(pofile)
         poelementsrc = str(pounit)
-        print poelementsrc
-        assert "Newline \n Newline" in pounit.source 
-        assert "Tab \t Tab" in pounit.source 
-        assert "CR \r CR" in pounit.source 
+        print(poelementsrc)
+        assert "Newline \n Newline" in pounit.source
+        assert "Tab \t Tab" in pounit.source
+        assert "CR \r CR" in pounit.source
 
     def test_roundtrip_escape(self):
         self.check_roundtrip('strings.src', r'The given command is not a SELECT statement.\nOnly queries are allowed.')
-        self.check_roundtrip('source\ui\dlg\AutoControls_tmpl.hrc', r';\t59\t,\t44\t:\t58\t{Tab}\t9\t{Space}\t32')
-        self.check_roundtrip('inc_openoffice\windows\msi_languages\Nsis.ulf', r'The installation files must be unpacked and copied to your hard disk in preparation for the installation. After that, the %PRODUCTNAME installation will start automatically.\r\n\r\nClick \'Next\' to continue.')
+        self.check_roundtrip('source\\ui\\dlg\\AutoControls_tmpl.hrc', r';\t59\t,\t44\t:\t58\t{Tab}\t9\t{Space}\t32')
+        self.check_roundtrip('inc_openoffice\\windows\\msi_languages\\Nsis.ulf', r'The installation files must be unpacked and copied to your hard disk in preparation for the installation. After that, the %PRODUCTNAME installation will start automatically.\r\n\r\nClick \'Next\' to continue.')
         self.check_roundtrip('file.xhp', r'\<ahelp\>')
         self.check_roundtrip('file.xhp', r'\<ahelp prop=\"value\"\>')
         self.check_roundtrip('file.xhp', r'\<ahelp prop=\"value\"\>marked up text\</ahelp\>')
@@ -89,18 +91,17 @@ class TestOO2PO:
         self.check_roundtrip('file.xhp', r'''\<ahelp prop=\"value>>\"\>'Next'>> or "<<Previous"\</ahelp\>''')
         self.check_roundtrip('address_auto.xhp', r'''example, \<item type=\"literal\"\>'Harry\\'s Bar'.\</item\>''')
 
-    def xtest_roundtrip_whitespaceonly(self):
+    def test_roundtrip_whitespaceonly(self):
         """check items that are only special instances of whitespce"""
-        # FIXME We can't roundtrip this yet because of some problems in the oo class handling
         self.check_roundtrip('choose_chart_type.xhp', r' ')
-        self.check_roundtrip('choose_chart_type.xhp', '\xc2\xa0')
+        self.check_roundtrip('choose_chart_type.xhp', b'\xc2\xa0'.decode('utf-8'))
 
     def test_double_escapes(self):
         oosource = r"helpcontent2	source\text\shared\01\02100001.xhp	0	help	par_id3150670 35				0	en-US	\\<				2002-02-02 02:02:02"
         pofile = self.convert(oosource)
         pounit = self.singleelement(pofile)
         poelementsrc = str(pounit)
-        print poelementsrc
+        print(poelementsrc)
         assert pounit.source == r"\<"
 
     def test_escapes_helpcontent2(self):
@@ -109,16 +110,25 @@ class TestOO2PO:
         pofile = self.convert(oosource)
         pounit = self.singleelement(pofile)
         poelementsrc = str(pounit)
-        print poelementsrc
+        print(poelementsrc)
         assert pounit.source == r'size *2 \langle x \rangle'
 
     def test_msgid_bug_error_address(self):
         """tests the we have the correct url for reporting msgid bugs"""
         oosource = r"wizards	source\formwizard\dbwizres.src	0	string	RID_DB_FORM_WIZARD_START + 19				0	en-US	Newline \n Newline Tab \t Tab CR \r CR				20050924 09:13:58"
-        bug_url = '''http://qa.openoffice.org/issues/enter_bug.cgi''' + ('''?subcomponent=ui&comment=&short_desc=Localization issue in file: &component=l10n&form_name=enter_issue''').replace(" ", "%20").replace(":", "%3A")
         pofile = self.convert(oosource)
         assert pofile.units[0].isheader()
-        assert pofile.parseheader()["Report-Msgid-Bugs-To"] == bug_url
+        assert pofile.parseheader()["Report-Msgid-Bugs-To"]
+        bug_url = parse.urlparse(pofile.parseheader()["Report-Msgid-Bugs-To"])
+        print(bug_url)
+        assert bug_url[:3] == ("http", "qa.openoffice.org", "/issues/enter_bug.cgi")
+        assert parse.parse_qs(bug_url[4], True) == {
+            'comment': [''],
+            'component': ['l10n'],
+            'form_name': ['enter_issue'],
+            'short_desc': ['Localization issue in file: '],
+            'subcomponent': ['ui'],
+        }
 
     def test_x_comment_inclusion(self):
         """test that we can merge x-comment language entries into comment sections of the PO file"""
@@ -159,13 +169,15 @@ class TestOO2PO:
             assert titleunit.source == "Title"
             assert titleunit.getnotes("developer") == ""
 
+
 class TestOO2POCommand(test_convert.TestConvertCommand, TestOO2PO):
     """Tests running actual oo2po commands on files"""
+
     convertmodule = oo2po
 
-    def test_help(self):
+    def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self)
+        options = test_convert.TestConvertCommand.test_help(self, capsys)
         options = self.help_check(options, "--source-language=LANG")
         options = self.help_check(options, "--language=LANG")
         options = self.help_check(options, "-P, --pot")
@@ -175,7 +187,7 @@ class TestOO2POCommand(test_convert.TestConvertCommand, TestOO2PO):
 
     def test_preserve_filename(self):
         """Ensures that the filename is preserved."""
-        oosource = r'svx	source\dialog\numpages.src	0	string	RID_SVXPAGE_NUM_OPTIONS	STR_BULLET			0	en-US	Character				20050924 09:13:58'
+        oosource = br'svx	source\dialog\numpages.src	0	string	RID_SVXPAGE_NUM_OPTIONS	STR_BULLET			0	en-US	Character				20050924 09:13:58'
         self.create_testfile("snippet.sdf", oosource)
         oofile = oo.oofile(self.open_testfile("snippet.sdf"))
         assert oofile.filename.endswith("snippet.sdf")
@@ -224,5 +236,4 @@ sd	source\ui\animations\CustomAnimationSchemesPane.src	0	checkbox	DLG_CUSTOMANIM
         self.run_command("simple.oo", "simple.po", language="fr", multifile="onefile", error="traceback", duplicates="merge")
         pofile = self.target_filetype(self.open_testfile("simple.po"))
         assert len(pofile.units) == 2
-        assert pofile.units[1].target == u"Aperçu automatique"
-
+        assert pofile.units[1].target == "Aperçu automatique"
