@@ -1,14 +1,11 @@
-#!/usr/bin/env python
 
 import os
 import warnings
+from io import BytesIO
 
 from pytest import mark
 
-from translate.convert import po2oo
-from translate.convert import oo2po
-from translate.convert import test_convert
-from translate.misc import wStringIO
+from translate.convert import oo2po, po2oo, test_convert
 from translate.storage import po
 
 
@@ -22,26 +19,26 @@ class TestPO2OO:
 
     def convertoo(self, posource, ootemplate, language="en-US"):
         """helper to exercise the command line function"""
-        inputfile = wStringIO.StringIO(posource)
-        outputfile = wStringIO.StringIO()
-        templatefile = wStringIO.StringIO(ootemplate)
+        inputfile = BytesIO(posource.encode())
+        outputfile = BytesIO()
+        templatefile = BytesIO(ootemplate.encode())
         assert po2oo.convertoo(inputfile, outputfile, templatefile, targetlanguage=language, timestamp=0)
         return outputfile.getvalue()
 
     def roundtripstring(self, entitystring):
         oointro, oooutro = r'svx	source\dialog\numpages.src	0	string	RID_SVXPAGE_NUM_OPTIONS	STR_BULLET			0	en-US	', '				2002-02-02 02:02:02' + '\r\n'
         oosource = oointro + entitystring + oooutro
-        ooinputfile = wStringIO.StringIO(oosource)
-        ooinputfile2 = wStringIO.StringIO(oosource)
-        pooutputfile = wStringIO.StringIO()
+        ooinputfile = BytesIO(oosource.encode())
+        ooinputfile2 = BytesIO(oosource.encode())
+        pooutputfile = BytesIO()
         oo2po.convertoo(ooinputfile, pooutputfile, ooinputfile2, targetlanguage='en-US')
         posource = pooutputfile.getvalue()
-        poinputfile = wStringIO.StringIO(posource)
-        ootemplatefile = wStringIO.StringIO(oosource)
-        oooutputfile = wStringIO.StringIO()
+        poinputfile = BytesIO(posource)
+        ootemplatefile = BytesIO(oosource.encode())
+        oooutputfile = BytesIO()
         po2oo.convertoo(poinputfile, oooutputfile, ootemplatefile, targetlanguage="en-US")
-        ooresult = oooutputfile.getvalue()
-        print "original oo:\n", oosource, "po version:\n", posource, "output oo:\n", ooresult
+        ooresult = oooutputfile.getvalue().decode('utf-8')
+        print("original oo:\n", oosource, "po version:\n", posource, "output oo:\n", ooresult)
         assert ooresult.startswith(oointro) and ooresult.endswith(oooutro)
         return ooresult[len(oointro):-len(oooutro)]
 
@@ -49,6 +46,7 @@ class TestPO2OO:
         """Checks that the round-tripped string is the same as the original"""
         assert self.roundtripstring(oosource) == oosource
 
+    @mark.skipif(os.name == 'nt', reason="test or storage broken on Windows")
     def test_convertoo(self):
         """checks that the convertoo function is working"""
         oobase = r'svx	source\dialog\numpages.src	0	string	RID_SVXPAGE_NUM_OPTIONS	STR_BULLET			0	%s	%s				20050924 09:13:58' + '\r\n'
@@ -56,12 +54,12 @@ class TestPO2OO:
         ootemplate = oobase % ('en-US', 'Simple String')
         ooexpected = oobase % ('zu', 'Dimpled Ring')
         newoo = self.convertoo(posource, ootemplate, language="zu")
-        assert newoo == ootemplate + ooexpected
+        assert newoo.decode('utf-8') == ootemplate + ooexpected
 
     def test_pofilter(self):
         """Tests integration with pofilter"""
         #Some bad po with a few errors:
-        posource = '#: sourcefile.bla#ID_NUMBER.txet.gnirts\nmsgid "<tag cow=\\"3\\">Mistake."\nmsgstr "  <etiket koei=\\"3\\">(fout) "'
+        posource = b'#: sourcefile.bla#ID_NUMBER.txet.gnirts\nmsgid "<tag cow=\\"3\\">Mistake."\nmsgstr "  <etiket koei=\\"3\\">(fout) "'
         filter = po2oo.filter
         pofile = po.pofile()
         pofile.parse(posource)
@@ -93,7 +91,6 @@ class TestPO2OO:
         self.check_roundtrip(r'''"Single-Quote Escape \' "''')
         self.check_roundtrip(r"""'Both Quotes "" '' '""")
 
-    @mark.xfail(reason="this test fails because the resultant PO file returns as po.isempty since...")
     def test_roundtrip_spaces(self):
         # FIXME: this test fails because the resultant PO file returns as po.isempty since .isblank returns true
         # which is caused by isblankmsgtr returning True.  Its a complete mess which would mean unravelling lots
@@ -101,27 +98,27 @@ class TestPO2OO:
         # once we've fixed that.
         """checks that (escaped) quotes in strings make it through a oo->po->oo roundtrip"""
         self.check_roundtrip(" ")
-        self.check_roundtrip(u"\u00a0")
+        self.check_roundtrip("\u00a0")
 
     def test_default_timestamp(self):
         """test to ensure that we revert to the default timestamp"""
         oointro, oooutro = r'svx	source\dialog\numpages.src	0	string	RID_SVXPAGE_NUM_OPTIONS	STR_BULLET			0	en-US	Text				', '\r\n'
         posource = '''#: numpages.src#RID_SVXPAGE_NUM_OPTIONS.STR_BULLET.string.text\nmsgid "Text"\nmsgstr "Text"\n'''
-        inputfile = wStringIO.StringIO(posource)
-        outputfile = wStringIO.StringIO()
-        templatefile = wStringIO.StringIO(oointro + '20050924 09:13:58' + oooutro)
+        inputfile = BytesIO(posource.encode())
+        outputfile = BytesIO()
+        templatefile = BytesIO((oointro + '20050924 09:13:58' + oooutro).encode())
         assert po2oo.convertoo(inputfile, outputfile, templatefile, targetlanguage="en-US")
-        assert outputfile.getvalue() == oointro + '2002-02-02 02:02:02' + oooutro
+        assert outputfile.getvalue().decode('utf-8') == oointro + '2002-02-02 02:02:02' + oooutro
 
     def test_escape_conversion(self):
         """test to ensure that we convert escapes correctly"""
         oosource = r'svx	source\dialog\numpages.src	0	string	RID_SVXPAGE_NUM_OPTIONS	STR_BULLET			0	en-US	Column1\tColumn2\r\n				2002-02-02 02:02:02' + '\r\n'
         posource = '''#: numpages.src#RID_SVXPAGE_NUM_OPTIONS.STR_BULLET.string.text\nmsgid "Column1\\tColumn2\\r\\n"\nmsgstr "Kolom1\\tKolom2\\r\\n"\n'''
-        inputfile = wStringIO.StringIO(posource)
-        outputfile = wStringIO.StringIO()
-        templatefile = wStringIO.StringIO(oosource)
+        inputfile = BytesIO(posource.encode())
+        outputfile = BytesIO()
+        templatefile = BytesIO(oosource.encode())
         assert po2oo.convertoo(inputfile, outputfile, templatefile, targetlanguage="af-ZA")
-        assert "\tKolom1\\tKolom2\\r\\n\t" in outputfile.getvalue()
+        assert b"\tKolom1\\tKolom2\\r\\n\t" in outputfile.getvalue()
 
     def test_helpcontent_escapes(self):
         """test to ensure that we convert helpcontent escapes correctly"""
@@ -137,11 +134,11 @@ msgstr ""
 "<ahelp  hid=\".\" >Zeee 3DDDD-Settings toolbar controls properties of selected 3D "
 "objects.</ahelp>"
 '''
-        inputfile = wStringIO.StringIO(posource)
-        outputfile = wStringIO.StringIO()
-        templatefile = wStringIO.StringIO(oosource)
+        inputfile = BytesIO(posource.encode())
+        outputfile = BytesIO()
+        templatefile = BytesIO(oosource.encode())
         assert po2oo.convertoo(inputfile, outputfile, templatefile, targetlanguage="af-ZA")
-        assert r"\<ahelp  hid=\".\" \>Zeee 3DDDD-Settings toolbar controls properties of selected 3D objects.\</ahelp\>" in outputfile.getvalue()
+        assert br"\<ahelp  hid=\".\" \>Zeee 3DDDD-Settings toolbar controls properties of selected 3D objects.\</ahelp\>" in outputfile.getvalue()
 
     def test_helpcontent_escapes2(self):
         """test to ensure that we convert helpcontent escapes correctly"""
@@ -150,20 +147,21 @@ msgstr ""
 msgid "A1: <empty>"
 msgstr "Aa1: <empty>"
 '''
-        inputfile = wStringIO.StringIO(posource)
-        outputfile = wStringIO.StringIO()
-        templatefile = wStringIO.StringIO(oosource)
+        inputfile = BytesIO(posource.encode())
+        outputfile = BytesIO()
+        templatefile = BytesIO(oosource.encode())
         assert po2oo.convertoo(inputfile, outputfile, templatefile, targetlanguage="af-ZA")
-        assert r"Aa1: <empty>" in outputfile.getvalue()
+        assert b"Aa1: <empty>" in outputfile.getvalue()
 
 
 class TestPO2OOCommand(test_convert.TestConvertCommand, TestPO2OO):
     """Tests running actual po2oo commands on files"""
+
     convertmodule = po2oo
 
-    def test_help(self):
+    def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self)
+        options = test_convert.TestConvertCommand.test_help(self, capsys)
         options = self.help_check(options, "--source-language=LANG")
         options = self.help_check(options, "--language=LANG")
         options = self.help_check(options, "-T, --keeptimestamp")
@@ -177,11 +175,6 @@ class TestPO2OOCommand(test_convert.TestConvertCommand, TestPO2OO):
         options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "--multifile=MULTIFILESTYLE", last=True)
 
-    def merge2oo(self, oosource, posource):
-        """helper that merges po translations to oo source through files"""
-        outputoo = convertor.convertstore(inputpo)
-        return outputoo
-
     def convertoo(self, posource, ootemplate, language="en-US"):
         """helper to exercise the command line function"""
         self.create_testfile(os.path.join("input", "svx", "source", "dialog.po"), posource)
