@@ -1,18 +1,18 @@
-# -*- coding: utf-8 -*-
+
+from io import BytesIO
 
 from translate.convert import po2ts, test_convert
-from translate.misc import wStringIO
 from translate.storage import po
 
 
-class TestPO2TS(object):
+class TestPO2TS:
 
     def po2ts(self, posource):
         """helper that converts po source to ts source without requiring files"""
-        inputfile = wStringIO.StringIO(posource)
+        inputfile = BytesIO(posource.encode())
         inputpo = po.pofile(inputfile)
         convertor = po2ts.po2ts()
-        output = wStringIO.StringIO()
+        output = BytesIO()
         convertor.convertstore(inputpo, output)
         return output.getvalue().decode('utf-8')
 
@@ -41,9 +41,9 @@ msgstr "†arget"'''
         tsfile = self.po2ts(minipo)
         print(tsfile)
         print(type(tsfile))
-        assert u"<name>unicode.cpp</name>" in tsfile
-        assert u"<source>ßource</source>" in tsfile
-        assert u"<translation>†arget</translation>" in tsfile
+        assert "<name>unicode.cpp</name>" in tsfile
+        assert "<source>ßource</source>" in tsfile
+        assert "<translation>†arget</translation>" in tsfile
 
     def test_fullunit(self):
         """check that an entry with various settings is converted correctly"""
@@ -103,7 +103,7 @@ msgstr "Linea 1\n"
         tsfile = self.po2ts(minipo)
         print(tsfile)
         print(type(tsfile))
-        assert u"<name>linebreak.cpp</name>" in tsfile
+        assert "<name>linebreak.cpp</name>" in tsfile
         assert r'''<source>Line 1
 Line 2</source>''' in tsfile
         assert r'''<translation>Linea 1
@@ -121,7 +121,7 @@ msgstr "Linea 1\n"
         tsfile = self.po2ts(minipo)
         print(tsfile)
         print(type(tsfile))
-        assert u"<name>linebreak.cpp</name>" in tsfile
+        assert "<name>linebreak.cpp</name>" in tsfile
         assert r'''<source>Line 1
 
 Line 3</source>''' in tsfile
@@ -132,6 +132,7 @@ Linea 3</translation>''' in tsfile
 
 class TestPO2TSCommand(test_convert.TestConvertCommand, TestPO2TS):
     """Tests running actual po2ts commands on files"""
+
     convertmodule = po2ts
 
     def test_help(self, capsys):
