@@ -1,13 +1,10 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 import warnings
+from io import BytesIO
 
 from pytest import mark
 
-from translate.convert import pot2po
-from translate.convert import test_convert
-from translate.misc import wStringIO
+from translate.convert import pot2po, test_convert
 from translate.storage import po
 
 
@@ -21,12 +18,12 @@ class TestPOT2PO:
 
     def convertpot(self, potsource, posource=None):
         """helper that converts pot source to po source without requiring files"""
-        potfile = wStringIO.StringIO(potsource)
+        potfile = BytesIO(potsource.encode())
         if posource:
-            pofile = wStringIO.StringIO(posource)
+            pofile = BytesIO(posource.encode())
         else:
             pofile = None
-        pooutfile = wStringIO.StringIO()
+        pooutfile = BytesIO()
         pot2po.convertpot(potfile, pooutfile, pofile)
         pooutfile.seek(0)
         return po.pofile(pooutfile.read())
@@ -35,7 +32,7 @@ class TestPOT2PO:
         """checks that the pofile contains a single non-header unit, and returns it"""
         assert len(pofile.units) == 2
         assert pofile.units[0].isheader()
-        print pofile.units[1]
+        print(pofile.units[1])
         return pofile.units[1]
 
     def test_convertpot_blank(self):
@@ -113,7 +110,7 @@ msgstr[1] "%d handleidings."
         posource = '''#: simple.label\n#: simple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n'''
         poexpected = '''#: simple.label\n#: simple.accesskey\n#, fuzzy\nmsgid "Its &hard coding a newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n'''
         newpo = self.convertpot(potsource, posource)
-        print newpo
+        print(newpo)
         assert str(self.singleunit(newpo)) == poexpected
 
     def test_merging_location_change(self):
@@ -122,30 +119,35 @@ msgstr[1] "%d handleidings."
         posource = '''#: simple.label%ssimple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n''' % po.lsep
         poexpected = '''#: new_simple.label%snew_simple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n''' % po.lsep
         newpo = self.convertpot(potsource, posource)
-        print newpo
+        print(newpo)
         assert str(self.singleunit(newpo)) == poexpected
 
     def test_merging_location_and_whitespace_change(self):
-        """test that even if the location changes that if the msgid
-        only has whitespace changes we can still merge"""
+        """
+        test that even if the location changes that if the msgid
+        only has whitespace changes we can still merge
+        """
 
         potsource = '''#: singlespace.label%ssinglespace.accesskey\nmsgid "&We have spaces"\nmsgstr ""\n''' % po.lsep
         posource = '''#: doublespace.label%sdoublespace.accesskey\nmsgid "&We  have  spaces"\nmsgstr "&One  het  spasies"\n''' % po.lsep
         poexpected = '''#: singlespace.label%ssinglespace.accesskey\n#, fuzzy\nmsgid "&We have spaces"\nmsgstr "&One  het  spasies"\n''' % po.lsep
         newpo = self.convertpot(potsource, posource)
-        print newpo
+        print(newpo)
         assert str(self.singleunit(newpo)) == poexpected
 
     def test_merging_location_ambiguous_with_disambiguous(self):
-        """test that when we have a PO in ambiguous (Gettext form) and merge with disamabiguous (KDE comment form)
-        that we don't duplicate the location #: comments"""
+        """
+        test that when we have a PO in ambiguous (Gettext form) and merge with
+        disamabiguous (KDE comment form) that we don't duplicate the
+        location #: comments
+        """
         potsource = '''#: location.c:1\nmsgid ""\n"_: location.c:1\\n"\n"Source"\nmsgstr ""\n\n''' + \
                     '''#: location.c:10\nmsgid ""\n"_: location.c:10\\n"\n"Source"\nmsgstr ""\n'''
         posource = '''#: location.c:1\n#: location.c:10\nmsgid "Source"\nmsgstr "Target"\n\n'''
         poexpected1 = '''#: location.c:1\n#, fuzzy\nmsgid ""\n"_: location.c:1\\n"\n"Source"\nmsgstr "Target"\n'''
         poexpected2 = '''#: location.c:10\n#, fuzzy\nmsgid ""\n"_: location.c:10\\n"\n"Source"\nmsgstr "Target"\n'''
         newpo = self.convertpot(potsource, posource)
-        print "Expected:\n", poexpected1, "Actual:\n", newpo.units[1]
+        print("Expected:\n", poexpected1, "Actual:\n", newpo.units[1])
         assert str(newpo.units[1]) == poexpected1
         assert str(newpo.units[2]) == poexpected2
 
@@ -156,7 +158,7 @@ msgstr[1] "%d handleidings."
         posource = '''#: someline.c\nmsgid "&About"\nmsgstr "&Info"\n'''
         poexpected = '''#: someline.c\nmsgid "A&bout"\nmsgstr "&Info"\n'''
         newpo = self.convertpot(potsource, posource)
-        print newpo
+        print(newpo)
         assert str(self.singleunit(newpo)) == poexpected
 
     @mark.xfail(reason="Not Implemented - review if this is even correct")
@@ -210,10 +212,10 @@ msgstr "Sekuriteit"
         poexpected = posource
         newpo = self.convertpot(potsource, posource)
         newpounit = self.singleunit(newpo)
-        print "expected"
-        print poexpected
-        print "got:"
-        print str(newpounit)
+        print("expected")
+        print(poexpected)
+        print("got:")
+        print(str(newpounit))
         assert str(newpounit) == poexpected
 
     def test_merging_msgidcomments(self):
@@ -276,7 +278,7 @@ msgstr "Sertifikate"
         potsource = '''msgid "One"\nmsgid_plural "Two"\nmsgstr[0] ""\nmsgstr[1] ""\n'''
         posource = '''msgid "One"\nmsgid_plural "Two"\nmsgstr[0] "Een"\nmsgstr[1] "Twee"\nmsgstr[2] "Drie"\n'''
         newpo = self.convertpot(potsource, posource)
-        print newpo
+        print(newpo)
         newpounit = self.singleunit(newpo)
         assert str(newpounit) == posource
 
@@ -287,7 +289,7 @@ msgstr "Sertifikate"
         posource = '# Some comment\n#. Extracted comment\n#: obsoleteme:10\nmsgid "One"\nmsgstr "Een"\n'
         expected = '# Some comment\n#~ msgid "One"\n#~ msgstr "Een"\n'
         newpo = self.convertpot(potsource, posource)
-        print str(newpo)
+        print(bytes(newpo))
         newpounit = self.singleunit(newpo)
         assert str(newpounit) == expected
 
@@ -297,7 +299,7 @@ msgstr "Sertifikate"
         potsource = 'msgid ""\nmsgstr ""\n'
         posource = '#: obsoleteme:10\nmsgid "One"\nmsgstr ""\n'
         newpo = self.convertpot(potsource, posource)
-        print str(newpo)
+        print(bytes(newpo))
         # We should only have the header
         assert len(newpo.units) == 1
 
@@ -314,7 +316,7 @@ msgstr "Sertifikate"
 
         # Now test with real units present in posource
         posource2 = '''msgid "Old"\nmsgstr "Oud"\n'''
-        newpo = self.convertpot(potsource, posource)
+        newpo = self.convertpot(potsource, posource2)
         assert len(newpo.units) == 3
         assert newpo.units[0].isheader()
         assert newpo.units[2].isobsolete()
@@ -327,7 +329,7 @@ msgstr "Sertifikate"
         posource = '''#~ msgid "&About"\n#~ msgstr "&Omtrent"\n'''
         expected = '''#: resurect.c\nmsgid "&About"\nmsgstr "&Omtrent"\n'''
         newpo = self.convertpot(potsource, posource)
-        print newpo
+        print(newpo)
         assert len(newpo.units) == 2
         assert newpo.units[0].isheader()
         newpounit = self.singleunit(newpo)
@@ -341,7 +343,7 @@ msgstr "Sertifikate"
         expected1 = '''#: resurect1.c\nmsgid "About"\nmsgstr "Omtrent"\n'''
         expected2 = '''#: resurect2.c\n#, fuzzy\nmsgid ""\n"_: resurect2.c\\n"\n"About"\nmsgstr "Omtrent"\n'''
         newpo = self.convertpot(potsource, posource)
-        print newpo
+        print(newpo)
         assert len(newpo.units) == 3
         assert newpo.units[0].isheader()
         assert str(newpo.units[1]) == expected1
@@ -393,9 +395,9 @@ msgstr ""
 "X-Generator: Translate Toolkit 0.10rc2\n"
 '''
         newpo = self.convertpot(potsource, posource)
-        print 'Output Header:\n%s' % newpo
-        print 'Expected Header:\n%s' % expected
-        assert str(newpo) == expected
+        print('Output Header:\n%s' % newpo)
+        print('Expected Header:\n%s' % expected)
+        assert bytes(newpo).decode('utf-8') == expected
 
     def test_merging_comments(self):
         """Test that we can merge comments correctly"""
@@ -403,7 +405,7 @@ msgstr ""
         posource = '''#. Don't do it!\n#: file.py:2\nmsgid "One"\nmsgstr "Een"\n'''
         poexpected = '''#. Don't do it!\n#: file.py:1\nmsgid "One"\nmsgstr "Een"\n'''
         newpo = self.convertpot(potsource, posource)
-        print newpo
+        print(newpo)
         newpounit = self.singleunit(newpo)
         assert str(newpounit) == poexpected
 
@@ -414,7 +416,7 @@ msgstr ""
         poexpected = '''#: file.c:1\n#, c-format\nmsgid "%d pipes"\nmsgstr "%d pype"\n'''
         newpo = self.convertpot(potsource, posource)
         newpounit = self.singleunit(newpo)
-        print newpounit
+        print(newpounit)
         assert str(newpounit) == poexpected
 
         potsource = '''#: file.c:1\n#, c-format\nmsgid "%d computers"\nmsgstr ""\n'''
@@ -462,8 +464,8 @@ msgid "text"
 msgstr "teks"
 """
         newpo = self.convertpot(potsource, posource)
-        print newpo
-        assert poexpected in str(newpo)
+        print(newpo)
+        assert poexpected in bytes(newpo).decode('utf-8')
 
     def test_msgctxt_multiline(self):
         """Test multiline msgctxt fields."""
@@ -636,24 +638,26 @@ msgid ""
 msgstr "trans"
 """
         newpo = self.convertpot(potsource, posource)
-        print newpo
+        print(newpo)
         assert len(newpo.units) == 2
         assert newpo.units[0].isheader()
         unit = newpo.units[1]
-        assert unit.source == u""
-        assert unit.getid() == u"bla\04"
+        assert unit.source == ""
+        assert unit.getid() == "bla\04"
         assert unit.target == "trans"
         assert not unit.isfuzzy()
 
     def test_migrate_msgidcomment_to_msgctxt(self):
-        """Test that we migrate correctly from msgidcomments to msgctxt.
+        """
+        Test that we migrate correctly from msgidcomments to msgctxt.
 
-        This is needed for our move away from using msgidcomments for mozilla."""
+        This is needed for our move away from using msgidcomments for mozilla.
+        """
         potsource = r'''
 msgid ""
 msgstr ""
-"X-Merge-On: location\n"
 "X-Accelerator-Marker: &\n"
+"X-Merge-On: location\n"
 
 
 #: bla
@@ -674,12 +678,12 @@ msgid ""
 msgstr "trans"
 '''
         newpo = self.convertpot(potsource, posource)
-        print newpo
+        print(newpo)
         assert len(newpo.units) == 2
         assert newpo.units[0].isheader()
         unit = newpo.units[1]
-        assert unit.source == u""
-        assert unit.getid() == u"bla\04"
+        assert unit.source == ""
+        assert unit.getid() == "bla\04"
         assert unit.target == "trans"
         assert not unit.isfuzzy()
 
@@ -703,7 +707,7 @@ msgstr "Eerste eenheid"
 #~ msgstr "Ou eenheid3"
 """
         newpo = self.convertpot(potsource, posource)
-        print newpo
+        print(newpo)
         assert len(newpo.units) == 5
         assert newpo.units[1].getcontext() == 'newContext'
         # Search in unit string, because obsolete units can't return a context
@@ -711,8 +715,10 @@ msgstr "Eerste eenheid"
         assert 'msgctxt "context2"' in str(newpo.units[3])
 
     def test_small_strings(self):
-        """Test that units with small source strings are not incorrectly
-        populated by means of fuzzy matching."""
+        """
+        Test that units with small source strings are not incorrectly
+        populated by means of fuzzy matching.
+        """
         potsource = r'''#, fuzzy
 msgid ""
 msgstr ""
@@ -726,9 +732,9 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=INTEGER; plural=EXPRESSION;\n"
+"X-Accelerator-Marker: &\n"
 "X-Generator: Translate Toolkit 0.10rc2\n"
 "X-Merge-On: location\n"
-"X-Accelerator-Marker: &\n"
 
 #: new_disassociated_mozilla_accesskey
 msgid "R"
@@ -765,27 +771,28 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
+"X-Accelerator-Marker: &\n"
 "X-Generator: Translate Toolkit 0.10rc2\n"
 "X-Merge-On: location\n"
-"X-Accelerator-Marker: &\n"
 
 #: new_disassociated_mozilla_accesskey
 msgid "R"
 msgstr ""
 '''
         newpo = self.convertpot(potsource, posource)
-        print 'Output:\n%s' % newpo
-        print 'Expected:\n%s' % expected
-        assert str(newpo) == expected
+        print('Output:\n%s' % newpo)
+        print('Expected:\n%s' % expected)
+        assert bytes(newpo).decode('utf-8') == expected
 
 
 class TestPOT2POCommand(test_convert.TestConvertCommand, TestPOT2PO):
     """Tests running actual pot2po commands on files"""
+
     convertmodule = pot2po
 
-    def test_help(self):
+    def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self)
+        options = test_convert.TestConvertCommand.test_help(self, capsys)
         options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "-P, --pot")
         options = self.help_check(options, "--tm")
