@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2010 Zuza Software Foundation
 #
@@ -20,12 +19,9 @@
 """Module to guess the language ISO code based on the 'Language-Team' entry in
 the header of a Gettext PO file.
 """
-from __future__ import print_function, unicode_literals
 
 import re
 
-import six
-
 
 __all__ = ('LANG_TEAM_CONTACT_SNIPPETS', 'guess_language')
 
@@ -406,7 +402,7 @@ def _snippet_guesser(snippets_dict, string, filter_=_nofilter):
     before examination
     """
     string = filter_(string)
-    for possible_lang, snippets in six.iteritems(snippets_dict):
+    for possible_lang, snippets in snippets_dict.items():
         for snippet in snippets:
             if filter_(snippet) in string:
                 return possible_lang
@@ -438,6 +434,7 @@ def guess_language(team_string):
 
 if __name__ == "__main__":
     from sys import argv
+
     from translate.storage import factory
     for fname in argv[1:]:
         store = factory.getobject(fname)
