@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2002-2006 Zuza Software Foundation
 #
@@ -21,32 +20,26 @@
 or entire files (csvfile) for use with localisation
 """
 
-from __future__ import unicode_literals
 
-import six
-if six.PY2:
-    from backports import csv
-else:
-    import csv
+import csv
 
 from translate.storage import base
 
 
 class DefaultDialect(csv.excel):
     skipinitialspace = True
-    quoting = csv.QUOTE_NONNUMERIC
+    quoting = csv.QUOTE_ALL
     escapechar = '\\'
 
 
 csv.register_dialect('default', DefaultDialect)
 
 
-@six.python_2_unicode_compatible
 class csvunit(base.TranslationUnit):
     spreadsheetescapes = [("+", "\\+"), ("-", "\\-"), ("=", "\\="), ("'", "\\'")]
 
     def __init__(self, source=None):
-        super(csvunit, self).__init__(source)
+        super().__init__(source)
         self.location = ""
         self.source = source or ""
         self.target = ""
@@ -63,7 +56,7 @@ class csvunit(base.TranslationUnit):
         result = self.source
         context = self.context
         if context:
-            result = u"%s\04%s" % (context, result)
+            result = "%s\04%s" % (context, result)
 
         return result
 
@@ -115,8 +108,8 @@ class csvunit(base.TranslationUnit):
             else:
                 self.translator_comments = text
 
-    def removenotes(self):
-        self.translator_comments = u''
+    def removenotes(self, origin=None):
+        self.translator_comments = ''
 
     def isfuzzy(self):
         if self.fuzzy.lower() in ('1', 'x', 'true', 'yes', 'fuzzy'):
@@ -132,7 +125,7 @@ class csvunit(base.TranslationUnit):
     def match_header(self):
         """see if unit might be a header"""
         some_value = False
-        for key, value in six.iteritems(self.todict()):
+        for key, value in self.todict().items():
             if value:
                 some_value = True
             if key.lower() != 'fuzzy' and value and key.lower() != value.lower():
@@ -158,7 +151,7 @@ class csvunit(base.TranslationUnit):
         return source, target
 
     def fromdict(self, cedict, encoding='utf-8'):
-        for key, value in six.iteritems(cedict):
+        for key, value in cedict.items():
             rkey = fieldname_map.get(key, key)
             if value is None or key is None or key == EXTRA_KEY:
                 continue
@@ -248,9 +241,8 @@ def valid_fieldnames(fieldnames):
     return False
 
 
-def detect_header(sample, dialect, fieldnames):
+def detect_header(inputfile, dialect, fieldnames):
     """Test if file has a header or not, also returns number of columns in first row"""
-    inputfile = csv.StringIO(sample)
     try:
         reader = csv.reader(inputfile, dialect)
     except csv.Error:
@@ -279,7 +271,7 @@ class csvfile(base.TranslationStore):
     Extensions = ["csv"]
 
     def __init__(self, inputfile=None, fieldnames=None, encoding='auto'):
-        super(csvfile, self).__init__(encoding=encoding)
+        super().__init__(encoding=encoding)
         if not fieldnames:
             self.fieldnames = ['location', 'source', 'target', 'id', 'fuzzy', 'context', 'translator_comments', 'developer_comments']
         else:
@@ -291,32 +283,34 @@ class csvfile(base.TranslationStore):
             inputfile.close()
             self.parse(csvsrc)
 
-    def parse(self, csvsrc):
+    def parse(self, csvsrc, sample_length=1024):
         text, encoding = self.detect_encoding(csvsrc, default_encodings=['utf-8', 'utf-16'])
         #FIXME: raise parse error if encoding detection fails?
         self.encoding = encoding or 'utf-8'
 
         sniffer = csv.Sniffer()
-        sample = text[:1024]
+        if sample_length:
+            sample = text[:sample_length]
+        else:
+            sample = text
 
         try:
             self.dialect = sniffer.sniff(sample)
-            if not self.dialect.escapechar:
-                self.dialect.escapechar = '\\'
-                if self.dialect.quoting == csv.QUOTE_MINIMAL:
-                    #HACKISH: most probably a default, not real detection
-                    self.dialect.quoting = csv.QUOTE_ALL
-                    self.dialect.doublequote = True
+            if self.dialect.quoting == csv.QUOTE_MINIMAL:
+                #HACKISH: most probably a default, not real detection
+                self.dialect.quoting = csv.QUOTE_ALL
+                self.dialect.doublequote = True
         except csv.Error:
             self.dialect = 'default'
 
+        inputfile = csv.StringIO(text)
         try:
-            fieldnames = detect_header(sample, self.dialect, self.fieldnames)
+            fieldnames = detect_header(inputfile, self.dialect, self.fieldnames)
             self.fieldnames = fieldnames
         except csv.Error:
             pass
 
-        inputfile = csv.StringIO(text)
+        inputfile.seek(0)
         reader = try_dialects(inputfile, self.fieldnames, self.dialect)
 
         first_row = True
@@ -330,7 +324,7 @@ class csvfile(base.TranslationStore):
     def serialize(self, out):
         """Write to file"""
         source = self.getoutput()
-        if isinstance(source, six.text_type):
+        if isinstance(source, str):
             # Python 3
             out.write(source.encode(self.encoding))
         else:
