@@ -1,15 +1,14 @@
-# -*- coding: utf-8 -*-
 
 import os
 import time
 from collections import OrderedDict
+from io import BytesIO
 
-from translate.misc import wStringIO
 from translate.storage import po, poheader, poxliff
 
 
 def test_parseheaderstring():
-    """ test for the header parsing function"""
+    """test for the header parsing function"""
     source = r'''item1: one
 item2: two:two
 this item must get ignored because there is no colon sign in it
@@ -24,7 +23,7 @@ item3: three
 
 
 def test_update():
-    '''test the update function'''
+    """test the update function"""
     # do we really add nothing if add==False ?
     d = poheader.update({}, test='hello')
     assert len(d) == 0
@@ -52,7 +51,7 @@ def test_update():
 
 def poparse(posource):
     """helper that parses po source without requiring files"""
-    dummyfile = wStringIO.StringIO(posource)
+    dummyfile = BytesIO(posource.encode())
     return po.pofile(dummyfile)
 
 
@@ -100,8 +99,6 @@ def test_po_dates():
 
 
 def test_timezones():
-    pofile = po.pofile()
-
     # The following will only work on Unix because of tzset() and %z
     if 'tzset' in time.__dict__:
         os.environ['TZ'] = 'Asia/Kabul'
@@ -200,8 +197,10 @@ msgstr ""
 
 
 def test_plural_equation():
-    """test that we work with the equation even is the last semicolon is left out, since gettext
-    tools don't seem to mind"""
+    """
+    test that we work with the equation even is the last semicolon is left out, since gettext
+    tools don't seem to mind
+    """
     posource = r'''msgid ""
 msgstr ""
 "Plural-Forms: nplurals=2; plural=(n != 1)%s\n"
@@ -214,7 +213,7 @@ msgstr ""
         assert header.isheader()
         assert not header.isblank()
 
-        headeritems = pofile.parseheader()
+        pofile.parseheader()
         nplural, plural = pofile.getheaderplural()
         assert nplural == "2"
         assert plural == "(n != 1)"
@@ -235,7 +234,7 @@ msgstr ""
     assert header.isheader()
     assert not header.isblank()
 
-    headeritems = pofile.parseheader()
+    pofile.parseheader()
     nplural, plural = pofile.getheaderplural()
     assert nplural == "3"
     assert plural == "(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2)"
